@@ -1,4 +1,7 @@
 """ Core module blob host app settings
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
 """
 from django.conf import settings
 
